@@ -1,6 +1,6 @@
 # -*- coding:utf-8 -*-
 from trdb2py.config import loadConfig
-from trdb2py.trdb2 import simTradings, getAssetCandles, simTrading
+from trdb2py.trdb2 import simTradings, getAssetCandles, simTrading, getAssetCandles2
 from trdb2py.utils import str2asset, nextWeekDay, asset2str
 from trdb2py.timeutils import str2timestamp
 from trdb2py.pdutils import buildPNLReport
@@ -11,6 +11,7 @@ from trdb2py.statistics import (calcPNLWinRateInYear, buildPNLWinRateInYears,
 from trdb2py.plotly import (showAssetCandles, showHeatmap, showHeatmapWinRateInYears,
                             showWinRateInYears, showHeatmapWinRateInMonths, showWinRateInMonths,
                             showBarWinRateInMonths, showBarWinRateInYears, showBarWinRate4Month,
-                            showPNL, showPNLs, showPNLs2, showBarResponseRateInYears)
-from trdb2py.trdb2utils import analysisResult
+                            showPNL, showPNLs, showPNLs2, showBarResponseRateInYears,
+                            showAssetCandles2)
+from trdb2py.trdb2utils import analysisResult, getIndicatorInResult
 import trdb2py.trading2_pb2
