@@ -1,6 +1,7 @@
 # -*- coding:utf-8 -*-
 import trdb2py.trading2_pb2
 from datetime import datetime
+import pandas as pd
 
 
 def analysisResult(result: dict, dtFormat: str = '%Y-%m-%d') -> dict:
@@ -36,3 +37,22 @@ def analysisResult(result: dict, dtFormat: str = '%Y-%m-%d') -> dict:
         return {'startTime': startdt, 'endTime': enddt, 'valuesNums': valuesnums}
 
     return None
+
+
+def getIndicatorInResult(result: dict, indicatorName: str, dtFormat: str = '%Y-%m-%d') -> pd.DataFrame:
+    if len(result['pnl'].indicators) > 0:
+        for v in result['pnl'].indicators:
+            if v.fullname == indicatorName:
+                fv0 = {
+                    'val': [],
+                    'date': [],
+                }
+
+                for cd in v.data:
+                    fv0['val'].append([cd.vals[0]])
+                    fv0['date'].append(datetime.fromtimestamp(
+                        cd.ts).strftime(dtFormat))
+
+            return pd.DataFrame(fv0)
+
+    return None
